@@ -55,9 +55,10 @@ package Dist::Zilla::Plugin::Templates::File;
 
 use Moose;
 use namespace::autoclean;
+use version 0.77;
 
 # ABSTRACT: TODO: Convert any text file into template
-our $VERSION = 'v0.5.1'; # VERSION
+our $VERSION = 'v0.5.2'; # VERSION
 
 extends 'Dist::Zilla::File::InMemory';
 
@@ -138,8 +139,8 @@ sub chomp {                             ## no critic ( ProhibitBuiltinHomonyms )
 # TODO: Pass arguments recursively?
 
 sub fill_in {
-    my ( $self ) = @_;
-    $self->_plugin->fill_in_file( $self );
+    my ( $self, @args ) = @_;
+    $self->_plugin->fill_in_file( $self, @args );
     return $self;
 };
 
@@ -243,7 +244,7 @@ Dist::Zilla::Plugin::Templates::File - TODO: Convert any text file into template
 
 =head1 VERSION
 
-Version v0.5.1, released on 2015-09-23 11:54 UTC.
+Version v0.5.2, released on 2015-09-24 20:14 UTC.
 
 =head1 SYNOPSIS
 
